@@ -30,8 +30,6 @@
 	}
 	
 	## we supply our own JavaGD class
-	.setenv <- if (exists("Sys.setenv")) Sys.setenv else Sys.putenv
-	.setenv("JAVAGD_CLASS_NAME"="org/mutoss/gui/JavaGD")  
-	require(mutoss)
+	Sys.setenv("JAVAGD_CLASS_NAME"="org/mutoss/gui/JavaGD")
 	packageStartupMessage("\nFor starting the MuToss-GUI enter:\nmutossGUI()\n")
 }  
\ No newline at end of file
